//
//  YHMyNameCardAvatarInfoCell.swift
//  galaxy
//
//  Created by edy on 2024/6/18.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit

class YHMyNameCardAvatarInfoCell: UITableViewCell {
    typealias EditBlock = () -> ()
    var editBlock: EditBlock?
    static let cellReuseIdentifier = "YHMyNameCardAvatarInfoCell"
    
    let headWidth = 74.0
    
    lazy var headImgV:UIImageView = {
        let view = UIImageView()
        view.image = UIImage(named: "")
        view.layer.cornerRadius = 74.0/2.0
        view.backgroundColor = .red
        return view
    }()
    
    lazy var signImgV:UIImageView = {
        let view = UIImageView()
        view.image = UIImage(named: "people_sign")
        return view
    }()
    
    lazy var cardView: UIView = {
        let view = UIView()
        view.backgroundColor = .white
        let bgImgView = UIImageView(image: UIImage(named: "people_add_friend_bg"))
        view.addSubview(bgImgView)
        bgImgView.snp.makeConstraints { make in
            make.edges.equalToSuperview()
        }
        view.layer.cornerRadius = 3.0
        return view
    }()
    
    lazy var editBtn:UIButton = {
        let btn = UIButton()
        btn.setImage(UIImage(named: "people_card_edit"), for: .normal)
        btn.addTarget(self, action: #selector(edit), for: .touchUpInside)
        btn.YH_clickEdgeInsets = UIEdgeInsets(top: 20, left: 20, bottom: 20, right: 20)
        return btn
    }()
    
    lazy var nameLabel:UILabel = {
        let nameLabel = UILabel()
        nameLabel.textColor = UIColor.mainTextColor
        nameLabel.textAlignment = .left
        nameLabel.font = UIFont.PFSC_B(ofSize:18)
        return nameLabel
    }()
    
    lazy var cityLabel:UILabel = {
        let label = UILabel()
        label.textColor = UIColor.brandMainColor
        label.textAlignment = .center
        label.font = UIFont.PFSC_M(ofSize:12)
        label.backgroundColor = .brandMainColor8
        label.layer.cornerRadius = 3.0
        label.clipsToBounds = true
        label.text = "上海市"
        return label
    }()
    
    lazy var professionalLabel:UILabel = {
        let label = UILabel()
        label.textColor = UIColor.mainTextColor
        label.textAlignment = .left
        label.font = UIFont.PFSC_R(ofSize:14)
        label.numberOfLines = 0
        return label
    }()
    
    lazy var detailLabel:UILabel = {
        let label = UILabel()
        label.textColor = UIColor.mainTextColor50
        label.textAlignment = .left
        label.font = UIFont.PFSC_R(ofSize:13)
        label.numberOfLines = 0
        return label
    }()
    
    required init?(coder: NSCoder) {
        super.init(coder: coder)
    }
    
    override init(style: UITableViewCell.CellStyle, reuseIdentifier: String?) {
        super.init(style: style, reuseIdentifier: reuseIdentifier)
        setupUI()
    }
    
    func setupUI() {
        
        self.selectionStyle = .none
        self.backgroundColor = .clear
        self.contentView.backgroundColor = .clear
        
        self.contentView.addSubview(self.cardView)
        self.contentView.addSubview(self.headImgV)
        self.contentView.addSubview(self.signImgV)
        
        cardView.addSubview(self.nameLabel)
        cardView.addSubview(self.cityLabel)
        cardView.addSubview(self.professionalLabel)
        cardView.addSubview(self.detailLabel)
        cardView.addSubview(self.editBtn)

        self.nameLabel.text = "啊防守打法胜多负少"
        self.professionalLabel.text = "阿迪发沙发沙发撒发生大发三大发沙发沙发上1阿斯顿发双法防"
        self.detailLabel.text = "阿凡达所发生的发顺丰大沙发沙发沙发沙发沙发沙发沙发沙发沙发沙发沙发沙发发沙发"
        
        self.cardView.snp.makeConstraints { make in
            make.left.right.bottom.equalToSuperview()
            make.top.equalTo(self.headImgV.snp.centerY)
        }
        
        self.editBtn.snp.makeConstraints { make in
            make.width.height.equalTo(20)
            make.right.equalTo(-16)
            make.top.equalTo(16)
        }
        
        self.headImgV.snp.makeConstraints { make in
            make.width.height.equalTo(headWidth)
            make.left.equalTo(10)
            make.top.equalTo(0)
        }
        
        self.signImgV.snp.makeConstraints { make in
            make.width.equalTo(49)
            make.height.equalTo(17)
            make.bottom.equalTo(self.headImgV)
            make.centerX.equalTo(self.headImgV)
        }
        
        self.nameLabel.snp.makeConstraints { make in
            make.left.equalTo(16)
            make.top.equalTo(headWidth/2.0+10.0)
            make.height.equalTo(25)
        }
        
        self.cityLabel.snp.makeConstraints { make in
            make.left.equalTo(self.nameLabel.snp.right).offset(10)
            make.centerY.equalTo(self.nameLabel)
            make.height.equalTo(21)
            make.width.equalTo(44)
        }

        
        self.professionalLabel.snp.makeConstraints { make in
            make.left.equalTo(16)
            make.right.equalTo(-16)
            make.top.equalTo(self.nameLabel.snp.bottom).offset(8)
            make.height.greaterThanOrEqualTo(20)
        }
        
        self.detailLabel.snp.makeConstraints { make in
            make.left.equalTo(16)
            make.right.equalTo(-16)
            make.top.equalTo(self.professionalLabel.snp.bottom).offset(8)
            make.height.greaterThanOrEqualTo(18)
            make.bottom.equalTo(-16)
        }
    }
    
    @objc func edit() {
        if let block = editBlock {
            block()
        }
    }
}
