//
//  YHNameCardInfoView.swift
//  galaxy
//
//  Created by edy on 2024/6/18.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit
import DragCardContainer

class YHNameCardInfoView: DragCardView {

    static let height = 456.0
    static let width = KScreenWidth-36.0*2
    var sendBlock:(()->())?

    var cardModel:YHPeopleCardModel = YHPeopleCardModel()  {
        didSet {
            if self.cardModel.isSend {
                self.bottomBtn.setTitle("已发送好友申请", for: .normal)
                self.bottomBtn.backgroundColor = .brandMainColor30
                self.bottomBtn.isUserInteractionEnabled = false
            } else {
                self.bottomBtn.setTitle("交换名片", for: .normal)
                self.bottomBtn.backgroundColor = .brandMainColor
                self.bottomBtn.isUserInteractionEnabled = true
            }
        }
    }
    
    lazy var bgImgV:UIImageView = {
        let view = UIImageView()
        view.image = UIImage(named: "people_card_head_bg")
        view.backgroundColor = .red
        return view
    }()
    
    lazy var headImgV:UIImageView = {
        let view = UIImageView()
        view.image = UIImage(named: "")
        view.layer.cornerRadius = 98.0/2.0
        view.backgroundColor = .green
        return view
    }()
    
    lazy var signImgV:UIImageView = {
        let view = UIImageView()
        view.image = UIImage(named: "people_sign")
        return view
    }()
    
    lazy var nameLabel:UILabel = {
        let nameLabel = UILabel()
        nameLabel.textAlignment = .center
        nameLabel.textColor = UIColor.mainTextColor
        nameLabel.font = UIFont.PFSC_B(ofSize:18)
        return nameLabel
    }()
    
    lazy var professionalLabel:UILabel = {
        let label = UILabel()
        label.textAlignment = .center
        label.textColor = UIColor.mainTextColor
        label.font = UIFont.PFSC_R(ofSize:14)
        label.numberOfLines = 0
        return label
    }()
    
    lazy var grayContentView:UIView = {
        let view = UIView()
        view.backgroundColor = UIColor(hex: 0xF4F6FA)
        view.layer.cornerRadius = 3.0
        return view
    }()
    
    lazy var detailLabel:UILabel = {
        let label = UILabel()
        label.textColor = UIColor.mainTextColor50
        label.textAlignment = .left
        label.font = UIFont.PFSC_R(ofSize:13)
        label.numberOfLines = 0
        return label
    }()
    
    lazy var bottomBtn:UIButton = {
        let btn = UIButton()
        btn.backgroundColor = .brandMainColor
        btn.setTitle("交换名片", for: .normal)
        btn.setTitleColor(.white, for: .normal)
        btn.titleLabel?.font = .PFSC_M(ofSize: 15)
        btn.layer.cornerRadius = 3.0
        btn.addTarget(self, action: #selector(didBottomBtnClicked), for: .touchUpInside)
        return btn
    }()
    
    override init(frame: CGRect) {
        super.init(frame: frame)
        initUI()
        setupUI()
    }
    
    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    @objc func didBottomBtnClicked() {
       let view = YHFriendRequestView.createView()
       view.sendBlock = {
           [weak self] text in
           guard let self = self else { return }
           self.bottomBtn.setTitle("已发送好友申请", for: .normal)
           self.bottomBtn.backgroundColor = .brandMainColor30
           self.bottomBtn.isUserInteractionEnabled = false
           self.sendBlock?()
       }
       view.show()
    }
    
    static func createCardView() -> YHNameCardInfoView {
        let view = YHNameCardInfoView(frame: CGRect(x: 0, y: 0, width: Self.width, height: Self.height))
        return view
    }
    
    func show() {
        self.center = CGPointMake(KScreenWidth/2.0, KScreenHeight/2.0)
        UIApplication.shared.yhKeyWindow()?.addSubview(self)
        
    }
    
    private func initUI() {
        self.backgroundColor = .white
        self.layer.cornerRadius = 3.0
        self.clipsToBounds = true
    }
    
    private func setupUI() {
        
        self.contentView.addSubview(self.bgImgV)
        self.contentView.addSubview(self.headImgV)
        self.contentView.addSubview(self.signImgV)
        self.contentView.addSubview(self.nameLabel)
        self.contentView.addSubview(self.professionalLabel)
        self.contentView.addSubview(self.grayContentView)
        grayContentView.addSubview(self.detailLabel)
        self.contentView.addSubview(self.bottomBtn)
        
        nameLabel.text = "阿斯顿法师"
        professionalLabel.text = "啊发沙发沙发沙发沙发沙发三大发沙发的算法的算法的沙发沙发萨达1"
        detailLabel.text = "阿萨法法师懂法守法萨芬沙发沙发发说法发生发顺丰"
        
        self.bgImgV.snp.makeConstraints { make in
            make.left.top.right.equalToSuperview()
            make.height.equalTo(180)
        }
        
        self.headImgV.snp.makeConstraints { make in
            make.width.height.equalTo(98)
            make.centerX.equalToSuperview()
            make.bottom.equalTo(self.bgImgV).offset(20)
        }
        
        self.signImgV.snp.makeConstraints { make in
            make.centerX.equalTo(self.headImgV)
            make.width.equalTo(49)
            make.height.equalTo(17)
            make.bottom.equalTo(self.headImgV)
        }
        
        self.nameLabel.snp.makeConstraints { make in
            make.left.equalTo(18)
            make.right.equalTo(-18)
            make.height.equalTo(30)
            make.top.equalTo(self.signImgV.snp.bottom).offset(10)
            make.centerX.equalToSuperview()
        }
        
        self.professionalLabel.snp.makeConstraints { make in
            make.left.equalTo(18)
            make.right.equalTo(-18)
            make.height.equalTo(20)
            make.top.equalTo(self.nameLabel.snp.bottom).offset(8)
        }
        
        self.grayContentView.snp.makeConstraints { make in
            make.left.equalTo(18)
            make.right.equalTo(-18)
            make.height.equalTo(72)
            make.top.equalTo(self.professionalLabel.snp.bottom).offset(10)
        }
        
        self.detailLabel.snp.makeConstraints { make in
            make.left.top.equalTo(16)
            make.right.bottom.equalTo(-16)
        }

        self.bottomBtn.snp.makeConstraints { make in
            make.left.equalTo(18)
            make.right.equalTo(-18)
            make.height.equalTo(46)
            make.top.equalTo(self.grayContentView.snp.bottom).offset(32)

        }
    }
}
